==> apache-nuttx-12.5.1.tar.gz: nuttx/include/nuttx/timers/pl031.h <==
/****************************************************************************
 * include/nuttx/timers/pl031.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __INCLUDE_NUTTX_TIMER_PL031_H
#define __INCLUDE_NUTTX_TIMER_PL031_H

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

/****************************************************************************
 * Name: pl031_initialize
 *
 * Description:
 *   Initialize rtc device.
 *
 ****************************************************************************/

FAR struct rtc_lowerhalf_s *pl031_initialize(uintptr_t base, int irq);

#endif  //__INCLUDE_NUTTX_TIMER_PL031_H

==> apache-nuttx-12.6.0.tar.gz: nuttx/include/nuttx/timers/pl031.h <==
/****************************************************************************
 * include/nuttx/timers/pl031.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __INCLUDE_NUTTX_TIMERS_PL031_H
#define __INCLUDE_NUTTX_TIMERS_PL031_H

/****************************************************************************
 * Public Function Prototypes
 ****************************************************************************/

/****************************************************************************
 * Name: pl031_initialize
 *
 * Description:
 *   Initialize rtc device.
 *
 ****************************************************************************/

FAR struct rtc_lowerhalf_s *pl031_initialize(uintptr_t base, int irq);

#endif  /* __INCLUDE_NUTTX_TIMERS_PL031_H */
